@@ -22,7 +22,7 @@ class SlotShadowing(mixins.TargetedNamespaceWalker, mixins.SubclassWalker):
 
     @staticmethod
     def mk_name(kls):
-        return '%s.%s' % (kls.__module__, kls.__name__)
+        return f'{kls.__module__}.{kls.__name__}'
 
     def _should_ignore(self, kls):
         return self.mk_name(kls).split(".")[0] != self.target_namespace
@@ -56,8 +56,7 @@ class SlotShadowing(mixins.TargetedNamespaceWalker, mixins.SubclassWalker):
         if isinstance(slots, str):
             if self.err_if_slots_is_str:
                 pytest.fail(
-                    "cls %r; slots is %r (should be a tuple or list)" %
-                    (kls, slots))
+                    "cls {kls!r}; slots is {slots!r} (should be a tuple or list)")
             slots = (slots,)
 
         if slots is None:
@@ -66,7 +65,7 @@ class SlotShadowing(mixins.TargetedNamespaceWalker, mixins.SubclassWalker):
         if not isinstance(slots, tuple):
             if self.err_if_slots_is_mutable:
                 pytest.fail(
-                    "cls %r; slots is %r- - should be a tuple" % (kls, slots))
+                    "cls {kls!r}; slots is {slots!r}- - should be a tuple")
             slots = tuple(slots)
 
         if slots is None or (slots and slots in raw_slottings):
@@ -74,12 +73,10 @@ class SlotShadowing(mixins.TargetedNamespaceWalker, mixins.SubclassWalker):
             # this means that the child either didn't define __slots__, or
             # daftly copied the parents... thus defeating the purpose.
             pytest.fail(
-                "cls %r; slots is %r, seemingly inherited from %r; the "
-                "derivative class should be __slots__ = ()" %
-                (kls, slots, raw_slottings[slots]))
+                "cls {kls!r}; slots is {slots!r}, seemingly inherited from "
+                "{raw_slottings[slots]!r}; the derivative class should be __slots__ = ()")
 
         for slot in slots:
             if slot in slotting:
                 pytest.fail(
-                    "cls %r; slot %r was already defined at %r" %
-                    (kls, slot, slotting[slot]))
+                    "cls {kls!r}; slot {slot!r} was already defined at {slotting[slot]!r}")
